UNIT uAmpel;
(* ******************************************************************** *)
(* K L A S S E : TAmpel                                                 *)
(* -------------------------------------------------------------------- *)
(* Version     : 1.0                                                    *)
(* Autor       : S. Spolwig                                                       *)
(* Beschreibung: Die Klasse bildet eine dumme Ampel mit diskreten       *)
(*							 Lampen ab.                                             *)
(* Compiler    : Delphi 5.0                                             *)
(* Aenderungen : 0.9	11-MAY-01                                         *)
(* ******************************************************************** *)

INTERFACE
// =======================================================================
uses uLampe,
     uGrafik;
type
  TAmpel = class(TObject)
   private
   	Kasten      : TRechteck;
    RoteLampe,
    GelbeLampe,
    GrueneLampe : TLampe;
    XPosition,
    YPosition   : integer;    // wo sie steht
   public
    constructor Create;       // herstellen
    procedure Init;
    procedure Rot;            // Zustand
    procedure Gelb;
    procedure Gruen;

    procedure SetPosition(xp, yp: integer);
    procedure Zeigen;
    procedure Abschalten;
  end;
(* -------------------- B e s c h r e i b u n g -------------------------

Oberklasse     : -
Bezugsklassen  : TRechteck, TLampe

Methoden
--------

Init
  Auftrag: gesamte Ampel erzeugen mit Lampen
  vorher : TLampe existiert
  nachher: Kasten und Lampen erzeugt

Init
  Auftrag: den Lampen Fuellfarbe rot, gelb, gruen zuweisen
  vorher : -
  nachher: done

Rot
  Auftrag: auf ROT schalten
  vorher : -
  nacher : ROT, aus, aus.

Gelb
  Auftrag: auf GELB schalten
  vorher : -
  nacher : GELB, aus, aus.

Gruen
  Auftrag: auf GRUEN schalten
  vorher : -
  nacher : GRUEN, aus, aus.


SetPosition(xp, yp: integer);
  Auftrag: Position auf dem Zeichenblatt bergeben
  vorher : -
  nachher: done

Zeigen
  Auftrag: Ampel auf dem Zeichenblatt anzeigen im jeweiligen Zustand
  vorher : -
  nachher: done

Abschalten
  Auftrag: alle Lampen aus
  vorher : -
  nachher: alle Lampen sind dunkel

----------------------------------------------------------------------- *)

IMPLEMENTATION
// ====================================================================

uses graphics; // importiert TColor

constructor TAmpel.Create;
// --------------------------------------------------------------------
begin
  inherited create;
  Kasten := TRechteck.Create;
  Kasten.SetFuellFarbe(clGray);

  RoteLampe   := TLampe.Create;
  GelbeLampe  := TLampe.Create;
  GrueneLampe := TLampe.Create;
  Init;
end;


procedure TAmpel.Init;
// --------------------------------------------------------------------
begin
  RoteLampe.SetFuellFarbe(clRed);
  GelbeLampe.SetFuellFarbe(clYellow);
  GrueneLampe.SetFuellFarbe(clLime);
end;


procedure TAmpel.SetPosition(xp, yp : integer);
// --------------------------------------------------------------------
begin
  XPosition := xp;
  YPosition := yp;
  Kasten.SetPos(XPosition, YPosition, XPosition + 30, YPosition + 80);
  RoteLampe.SetPos(XPosition + 15, YPosition + 15);
  GelbeLampe.SetPos(XPosition + 15, YPosition + 40);
  GrueneLampe.SetPos(XPosition + 15, YPosition + 65);
end;


procedure TAmpel.Rot;
// --------------------------------------------------------------------
begin
   RoteLampe.Ein;
   GelbeLampe.Aus;
   GrueneLampe.Aus
end;

procedure TAmpel.Gelb;
// --------------------------------------------------------------------
begin
  RoteLampe.Aus;
  GelbeLampe.Ein;
  GrueneLampe.Aus;
end;

procedure TAmpel.Gruen;
// --------------------------------------------------------------------
begin
  RoteLampe.Aus;
  GelbeLampe.Aus;
  GrueneLampe.Ein;
end;

procedure TAmpel.Zeigen;
// --------------------------------------------------------------------
begin
  Kasten.Zeigen;
  RoteLampe.Zeigen;
  GelbeLampe.Zeigen;
  GrueneLampe.Zeigen;
end;

procedure TAmpel.Abschalten;
// --------------------------------------------------------------------
begin
  RoteLampe.Aus;
  GelbeLampe.Aus;
  GrueneLampe.Aus;
end;

END.
